@@ -27,15 +27,28 @@ __all__ = (
     "EnvironmentDeployedWaiterName",
     "EnvironmentTemplateVersionRegisteredWaiterName",
     "ListEnvironmentAccountConnectionsPaginatorName",
+    "ListEnvironmentOutputsPaginatorName",
+    "ListEnvironmentProvisionedResourcesPaginatorName",
     "ListEnvironmentTemplateVersionsPaginatorName",
     "ListEnvironmentTemplatesPaginatorName",
     "ListEnvironmentsPaginatorName",
+    "ListRepositoriesPaginatorName",
+    "ListRepositorySyncDefinitionsPaginatorName",
+    "ListServiceInstanceOutputsPaginatorName",
+    "ListServiceInstanceProvisionedResourcesPaginatorName",
     "ListServiceInstancesPaginatorName",
+    "ListServicePipelineOutputsPaginatorName",
+    "ListServicePipelineProvisionedResourcesPaginatorName",
     "ListServiceTemplateVersionsPaginatorName",
     "ListServiceTemplatesPaginatorName",
     "ListServicesPaginatorName",
     "ListTagsForResourcePaginatorName",
+    "ProvisionedResourceEngineType",
     "ProvisioningType",
+    "RepositoryProviderType",
+    "RepositorySyncStatusType",
+    "ResourceDeploymentStatusType",
+    "ResourceSyncStatusType",
     "ServiceCreatedWaiterName",
     "ServiceDeletedWaiterName",
     "ServiceInstanceDeployedWaiterName",
@@ -43,6 +56,8 @@ __all__ = (
     "ServiceStatusType",
     "ServiceTemplateVersionRegisteredWaiterName",
     "ServiceUpdatedWaiterName",
+    "SyncTypeType",
+    "TemplateTypeType",
     "TemplateVersionStatusType",
     "ServiceName",
     "PaginatorName",
@@ -68,15 +83,32 @@ EnvironmentAccountConnectionStatusType = Literal["CONNECTED", "PENDING", "REJECT
 EnvironmentDeployedWaiterName = Literal["environment_deployed"]
 EnvironmentTemplateVersionRegisteredWaiterName = Literal["environment_template_version_registered"]
 ListEnvironmentAccountConnectionsPaginatorName = Literal["list_environment_account_connections"]
+ListEnvironmentOutputsPaginatorName = Literal["list_environment_outputs"]
+ListEnvironmentProvisionedResourcesPaginatorName = Literal["list_environment_provisioned_resources"]
 ListEnvironmentTemplateVersionsPaginatorName = Literal["list_environment_template_versions"]
 ListEnvironmentTemplatesPaginatorName = Literal["list_environment_templates"]
 ListEnvironmentsPaginatorName = Literal["list_environments"]
+ListRepositoriesPaginatorName = Literal["list_repositories"]
+ListRepositorySyncDefinitionsPaginatorName = Literal["list_repository_sync_definitions"]
+ListServiceInstanceOutputsPaginatorName = Literal["list_service_instance_outputs"]
+ListServiceInstanceProvisionedResourcesPaginatorName = Literal[
+    "list_service_instance_provisioned_resources"
+]
 ListServiceInstancesPaginatorName = Literal["list_service_instances"]
+ListServicePipelineOutputsPaginatorName = Literal["list_service_pipeline_outputs"]
+ListServicePipelineProvisionedResourcesPaginatorName = Literal[
+    "list_service_pipeline_provisioned_resources"
+]
 ListServiceTemplateVersionsPaginatorName = Literal["list_service_template_versions"]
 ListServiceTemplatesPaginatorName = Literal["list_service_templates"]
 ListServicesPaginatorName = Literal["list_services"]
 ListTagsForResourcePaginatorName = Literal["list_tags_for_resource"]
+ProvisionedResourceEngineType = Literal["CLOUDFORMATION", "TERRAFORM"]
 ProvisioningType = Literal["CUSTOMER_MANAGED"]
+RepositoryProviderType = Literal["BITBUCKET", "GITHUB", "GITHUB_ENTERPRISE"]
+RepositorySyncStatusType = Literal["FAILED", "INITIATED", "IN_PROGRESS", "QUEUED", "SUCCEEDED"]
+ResourceDeploymentStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED"]
+ResourceSyncStatusType = Literal["FAILED", "INITIATED", "IN_PROGRESS", "SUCCEEDED"]
 ServiceCreatedWaiterName = Literal["service_created"]
 ServiceDeletedWaiterName = Literal["service_deleted"]
 ServiceInstanceDeployedWaiterName = Literal["service_instance_deployed"]
@@ -99,6 +131,8 @@ ServiceStatusType = Literal[
 ]
 ServiceTemplateVersionRegisteredWaiterName = Literal["service_template_version_registered"]
 ServiceUpdatedWaiterName = Literal["service_updated"]
+SyncTypeType = Literal["TEMPLATE_SYNC"]
+TemplateTypeType = Literal["ENVIRONMENT", "SERVICE"]
 TemplateVersionStatusType = Literal[
     "DRAFT", "PUBLISHED", "REGISTRATION_FAILED", "REGISTRATION_IN_PROGRESS"
 ]
@@ -115,6 +149,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -183,6 +218,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -289,6 +325,7 @@ ServiceName = Literal[
     "mgh",
     "mgn",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -322,6 +359,7 @@ ServiceName = Literal[
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -392,10 +430,18 @@ ServiceName = Literal[
 ]
 PaginatorName = Literal[
     "list_environment_account_connections",
+    "list_environment_outputs",
+    "list_environment_provisioned_resources",
     "list_environment_template_versions",
     "list_environment_templates",
     "list_environments",
+    "list_repositories",
+    "list_repository_sync_definitions",
+    "list_service_instance_outputs",
+    "list_service_instance_provisioned_resources",
     "list_service_instances",
+    "list_service_pipeline_outputs",
+    "list_service_pipeline_provisioned_resources",
     "list_service_template_versions",
     "list_service_templates",
     "list_services",
