@@ -20,7 +20,13 @@ from .literals import (
     DeploymentUpdateTypeType,
     EnvironmentAccountConnectionRequesterAccountTypeType,
     EnvironmentAccountConnectionStatusType,
+    ProvisionedResourceEngineType,
+    RepositoryProviderType,
+    RepositorySyncStatusType,
+    ResourceDeploymentStatusType,
+    ResourceSyncStatusType,
     ServiceStatusType,
+    TemplateTypeType,
     TemplateVersionStatusType,
 )
 
@@ -54,12 +60,16 @@ __all__ = (
     "CreateEnvironmentTemplateOutputTypeDef",
     "CreateEnvironmentTemplateVersionInputRequestTypeDef",
     "CreateEnvironmentTemplateVersionOutputTypeDef",
+    "CreateRepositoryInputRequestTypeDef",
+    "CreateRepositoryOutputTypeDef",
     "CreateServiceInputRequestTypeDef",
     "CreateServiceOutputTypeDef",
     "CreateServiceTemplateInputRequestTypeDef",
     "CreateServiceTemplateOutputTypeDef",
     "CreateServiceTemplateVersionInputRequestTypeDef",
     "CreateServiceTemplateVersionOutputTypeDef",
+    "CreateTemplateSyncConfigInputRequestTypeDef",
+    "CreateTemplateSyncConfigOutputTypeDef",
     "DeleteEnvironmentAccountConnectionInputRequestTypeDef",
     "DeleteEnvironmentAccountConnectionOutputTypeDef",
     "DeleteEnvironmentInputRequestTypeDef",
@@ -68,12 +78,16 @@ __all__ = (
     "DeleteEnvironmentTemplateOutputTypeDef",
     "DeleteEnvironmentTemplateVersionInputRequestTypeDef",
     "DeleteEnvironmentTemplateVersionOutputTypeDef",
+    "DeleteRepositoryInputRequestTypeDef",
+    "DeleteRepositoryOutputTypeDef",
     "DeleteServiceInputRequestTypeDef",
     "DeleteServiceOutputTypeDef",
     "DeleteServiceTemplateInputRequestTypeDef",
     "DeleteServiceTemplateOutputTypeDef",
     "DeleteServiceTemplateVersionInputRequestTypeDef",
     "DeleteServiceTemplateVersionOutputTypeDef",
+    "DeleteTemplateSyncConfigInputRequestTypeDef",
+    "DeleteTemplateSyncConfigOutputTypeDef",
     "EnvironmentAccountConnectionSummaryTypeDef",
     "EnvironmentAccountConnectionTypeDef",
     "EnvironmentSummaryTypeDef",
@@ -92,6 +106,10 @@ __all__ = (
     "GetEnvironmentTemplateOutputTypeDef",
     "GetEnvironmentTemplateVersionInputRequestTypeDef",
     "GetEnvironmentTemplateVersionOutputTypeDef",
+    "GetRepositoryInputRequestTypeDef",
+    "GetRepositoryOutputTypeDef",
+    "GetRepositorySyncStatusInputRequestTypeDef",
+    "GetRepositorySyncStatusOutputTypeDef",
     "GetServiceInputRequestTypeDef",
     "GetServiceInstanceInputRequestTypeDef",
     "GetServiceInstanceOutputTypeDef",
@@ -100,16 +118,36 @@ __all__ = (
     "GetServiceTemplateOutputTypeDef",
     "GetServiceTemplateVersionInputRequestTypeDef",
     "GetServiceTemplateVersionOutputTypeDef",
+    "GetTemplateSyncConfigInputRequestTypeDef",
+    "GetTemplateSyncConfigOutputTypeDef",
+    "GetTemplateSyncStatusInputRequestTypeDef",
+    "GetTemplateSyncStatusOutputTypeDef",
     "ListEnvironmentAccountConnectionsInputRequestTypeDef",
     "ListEnvironmentAccountConnectionsOutputTypeDef",
+    "ListEnvironmentOutputsInputRequestTypeDef",
+    "ListEnvironmentOutputsOutputTypeDef",
+    "ListEnvironmentProvisionedResourcesInputRequestTypeDef",
+    "ListEnvironmentProvisionedResourcesOutputTypeDef",
     "ListEnvironmentTemplateVersionsInputRequestTypeDef",
     "ListEnvironmentTemplateVersionsOutputTypeDef",
     "ListEnvironmentTemplatesInputRequestTypeDef",
     "ListEnvironmentTemplatesOutputTypeDef",
     "ListEnvironmentsInputRequestTypeDef",
     "ListEnvironmentsOutputTypeDef",
+    "ListRepositoriesInputRequestTypeDef",
+    "ListRepositoriesOutputTypeDef",
+    "ListRepositorySyncDefinitionsInputRequestTypeDef",
+    "ListRepositorySyncDefinitionsOutputTypeDef",
+    "ListServiceInstanceOutputsInputRequestTypeDef",
+    "ListServiceInstanceOutputsOutputTypeDef",
+    "ListServiceInstanceProvisionedResourcesInputRequestTypeDef",
+    "ListServiceInstanceProvisionedResourcesOutputTypeDef",
     "ListServiceInstancesInputRequestTypeDef",
     "ListServiceInstancesOutputTypeDef",
+    "ListServicePipelineOutputsInputRequestTypeDef",
+    "ListServicePipelineOutputsOutputTypeDef",
+    "ListServicePipelineProvisionedResourcesInputRequestTypeDef",
+    "ListServicePipelineProvisionedResourcesOutputTypeDef",
     "ListServiceTemplateVersionsInputRequestTypeDef",
     "ListServiceTemplateVersionsOutputTypeDef",
     "ListServiceTemplatesInputRequestTypeDef",
@@ -118,10 +156,23 @@ __all__ = (
     "ListServicesOutputTypeDef",
     "ListTagsForResourceInputRequestTypeDef",
     "ListTagsForResourceOutputTypeDef",
+    "NotifyResourceDeploymentStatusChangeInputRequestTypeDef",
+    "OutputTypeDef",
     "PaginatorConfigTypeDef",
+    "ProvisionedResourceTypeDef",
     "RejectEnvironmentAccountConnectionInputRequestTypeDef",
     "RejectEnvironmentAccountConnectionOutputTypeDef",
+    "RepositoryBranchInputTypeDef",
+    "RepositoryBranchTypeDef",
+    "RepositorySummaryTypeDef",
+    "RepositorySyncAttemptTypeDef",
+    "RepositorySyncDefinitionTypeDef",
+    "RepositorySyncEventTypeDef",
+    "RepositoryTypeDef",
+    "ResourceSyncAttemptTypeDef",
+    "ResourceSyncEventTypeDef",
     "ResponseMetadataTypeDef",
+    "RevisionTypeDef",
     "S3ObjectSourceTypeDef",
     "ServiceInstanceSummaryTypeDef",
     "ServiceInstanceTypeDef",
@@ -134,6 +185,7 @@ __all__ = (
     "ServiceTypeDef",
     "TagResourceInputRequestTypeDef",
     "TagTypeDef",
+    "TemplateSyncConfigTypeDef",
     "TemplateVersionSourceInputTypeDef",
     "UntagResourceInputRequestTypeDef",
     "UpdateAccountSettingsInputRequestTypeDef",
@@ -156,6 +208,8 @@ __all__ = (
     "UpdateServiceTemplateOutputTypeDef",
     "UpdateServiceTemplateVersionInputRequestTypeDef",
     "UpdateServiceTemplateVersionOutputTypeDef",
+    "UpdateTemplateSyncConfigInputRequestTypeDef",
+    "UpdateTemplateSyncConfigOutputTypeDef",
     "WaiterConfigTypeDef",
 )
 
@@ -177,6 +231,7 @@ AcceptEnvironmentAccountConnectionOutputTypeDef = TypedDict(
 AccountSettingsTypeDef = TypedDict(
     "AccountSettingsTypeDef",
     {
+        "pipelineProvisioningRepository": "RepositoryBranchTypeDef",
         "pipelineServiceRoleArn": str,
     },
     total=False,
@@ -256,6 +311,7 @@ _OptionalCreateEnvironmentAccountConnectionInputRequestTypeDef = TypedDict(
     "_OptionalCreateEnvironmentAccountConnectionInputRequestTypeDef",
     {
         "clientToken": str,
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -291,6 +347,7 @@ _OptionalCreateEnvironmentInputRequestTypeDef = TypedDict(
         "description": str,
         "environmentAccountConnectionId": str,
         "protonServiceRoleArn": str,
+        "provisioningRepository": "RepositoryBranchInputTypeDef",
         "tags": Sequence["TagTypeDef"],
         "templateMinorVersion": str,
     },
@@ -380,6 +437,37 @@ CreateEnvironmentTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateRepositoryInputRequestTypeDef = TypedDict(
+    "_RequiredCreateRepositoryInputRequestTypeDef",
+    {
+        "connectionArn": str,
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+_OptionalCreateRepositoryInputRequestTypeDef = TypedDict(
+    "_OptionalCreateRepositoryInputRequestTypeDef",
+    {
+        "encryptionKey": str,
+    },
+    total=False,
+)
+
+
+class CreateRepositoryInputRequestTypeDef(
+    _RequiredCreateRepositoryInputRequestTypeDef, _OptionalCreateRepositoryInputRequestTypeDef
+):
+    pass
+
+
+CreateRepositoryOutputTypeDef = TypedDict(
+    "CreateRepositoryOutputTypeDef",
+    {
+        "repository": "RepositoryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateServiceInputRequestTypeDef = TypedDict(
     "_RequiredCreateServiceInputRequestTypeDef",
     {
@@ -486,6 +574,40 @@ CreateServiceTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateTemplateSyncConfigInputRequestTypeDef = TypedDict(
+    "_RequiredCreateTemplateSyncConfigInputRequestTypeDef",
+    {
+        "branch": str,
+        "repositoryName": str,
+        "repositoryProvider": RepositoryProviderType,
+        "templateName": str,
+        "templateType": TemplateTypeType,
+    },
+)
+_OptionalCreateTemplateSyncConfigInputRequestTypeDef = TypedDict(
+    "_OptionalCreateTemplateSyncConfigInputRequestTypeDef",
+    {
+        "subdirectory": str,
+    },
+    total=False,
+)
+
+
+class CreateTemplateSyncConfigInputRequestTypeDef(
+    _RequiredCreateTemplateSyncConfigInputRequestTypeDef,
+    _OptionalCreateTemplateSyncConfigInputRequestTypeDef,
+):
+    pass
+
+
+CreateTemplateSyncConfigOutputTypeDef = TypedDict(
+    "CreateTemplateSyncConfigOutputTypeDef",
+    {
+        "templateSyncConfig": "TemplateSyncConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DeleteEnvironmentAccountConnectionInputRequestTypeDef = TypedDict(
     "DeleteEnvironmentAccountConnectionInputRequestTypeDef",
     {
@@ -548,6 +670,22 @@ DeleteEnvironmentTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+DeleteRepositoryInputRequestTypeDef = TypedDict(
+    "DeleteRepositoryInputRequestTypeDef",
+    {
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+
+DeleteRepositoryOutputTypeDef = TypedDict(
+    "DeleteRepositoryOutputTypeDef",
+    {
+        "repository": "RepositoryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DeleteServiceInputRequestTypeDef = TypedDict(
     "DeleteServiceInputRequestTypeDef",
     {
@@ -595,6 +733,22 @@ DeleteServiceTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+DeleteTemplateSyncConfigInputRequestTypeDef = TypedDict(
+    "DeleteTemplateSyncConfigInputRequestTypeDef",
+    {
+        "templateName": str,
+        "templateType": TemplateTypeType,
+    },
+)
+
+DeleteTemplateSyncConfigOutputTypeDef = TypedDict(
+    "DeleteTemplateSyncConfigOutputTypeDef",
+    {
+        "templateSyncConfig": "TemplateSyncConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 EnvironmentAccountConnectionSummaryTypeDef = TypedDict(
     "EnvironmentAccountConnectionSummaryTypeDef",
     {
@@ -805,6 +959,7 @@ _OptionalEnvironmentTypeDef = TypedDict(
         "environmentAccountId": str,
         "protonServiceRoleArn": str,
         "provisioning": Literal["CUSTOMER_MANAGED"],
+        "provisioningRepository": "RepositoryBranchTypeDef",
         "spec": str,
     },
     total=False,
@@ -885,6 +1040,40 @@ GetEnvironmentTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+GetRepositoryInputRequestTypeDef = TypedDict(
+    "GetRepositoryInputRequestTypeDef",
+    {
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+
+GetRepositoryOutputTypeDef = TypedDict(
+    "GetRepositoryOutputTypeDef",
+    {
+        "repository": "RepositoryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetRepositorySyncStatusInputRequestTypeDef = TypedDict(
+    "GetRepositorySyncStatusInputRequestTypeDef",
+    {
+        "branch": str,
+        "repositoryName": str,
+        "repositoryProvider": RepositoryProviderType,
+        "syncType": Literal["TEMPLATE_SYNC"],
+    },
+)
+
+GetRepositorySyncStatusOutputTypeDef = TypedDict(
+    "GetRepositorySyncStatusOutputTypeDef",
+    {
+        "latestSync": "RepositorySyncAttemptTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetServiceInputRequestTypeDef = TypedDict(
     "GetServiceInputRequestTypeDef",
     {
@@ -948,6 +1137,41 @@ GetServiceTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+GetTemplateSyncConfigInputRequestTypeDef = TypedDict(
+    "GetTemplateSyncConfigInputRequestTypeDef",
+    {
+        "templateName": str,
+        "templateType": TemplateTypeType,
+    },
+)
+
+GetTemplateSyncConfigOutputTypeDef = TypedDict(
+    "GetTemplateSyncConfigOutputTypeDef",
+    {
+        "templateSyncConfig": "TemplateSyncConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetTemplateSyncStatusInputRequestTypeDef = TypedDict(
+    "GetTemplateSyncStatusInputRequestTypeDef",
+    {
+        "templateName": str,
+        "templateType": TemplateTypeType,
+        "templateVersion": str,
+    },
+)
+
+GetTemplateSyncStatusOutputTypeDef = TypedDict(
+    "GetTemplateSyncStatusOutputTypeDef",
+    {
+        "desiredState": "RevisionTypeDef",
+        "latestSuccessfulSync": "ResourceSyncAttemptTypeDef",
+        "latestSync": "ResourceSyncAttemptTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListEnvironmentAccountConnectionsInputRequestTypeDef = TypedDict(
     "_RequiredListEnvironmentAccountConnectionsInputRequestTypeDef",
     {
@@ -982,6 +1206,68 @@ ListEnvironmentAccountConnectionsOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListEnvironmentOutputsInputRequestTypeDef = TypedDict(
+    "_RequiredListEnvironmentOutputsInputRequestTypeDef",
+    {
+        "environmentName": str,
+    },
+)
+_OptionalListEnvironmentOutputsInputRequestTypeDef = TypedDict(
+    "_OptionalListEnvironmentOutputsInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListEnvironmentOutputsInputRequestTypeDef(
+    _RequiredListEnvironmentOutputsInputRequestTypeDef,
+    _OptionalListEnvironmentOutputsInputRequestTypeDef,
+):
+    pass
+
+
+ListEnvironmentOutputsOutputTypeDef = TypedDict(
+    "ListEnvironmentOutputsOutputTypeDef",
+    {
+        "nextToken": str,
+        "outputs": List["OutputTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListEnvironmentProvisionedResourcesInputRequestTypeDef = TypedDict(
+    "_RequiredListEnvironmentProvisionedResourcesInputRequestTypeDef",
+    {
+        "environmentName": str,
+    },
+)
+_OptionalListEnvironmentProvisionedResourcesInputRequestTypeDef = TypedDict(
+    "_OptionalListEnvironmentProvisionedResourcesInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListEnvironmentProvisionedResourcesInputRequestTypeDef(
+    _RequiredListEnvironmentProvisionedResourcesInputRequestTypeDef,
+    _OptionalListEnvironmentProvisionedResourcesInputRequestTypeDef,
+):
+    pass
+
+
+ListEnvironmentProvisionedResourcesOutputTypeDef = TypedDict(
+    "ListEnvironmentProvisionedResourcesOutputTypeDef",
+    {
+        "nextToken": str,
+        "provisionedResources": List["ProvisionedResourceTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListEnvironmentTemplateVersionsInputRequestTypeDef = TypedDict(
     "_RequiredListEnvironmentTemplateVersionsInputRequestTypeDef",
     {
@@ -1052,6 +1338,121 @@ ListEnvironmentsOutputTypeDef = TypedDict(
     },
 )
 
+ListRepositoriesInputRequestTypeDef = TypedDict(
+    "ListRepositoriesInputRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListRepositoriesOutputTypeDef = TypedDict(
+    "ListRepositoriesOutputTypeDef",
+    {
+        "nextToken": str,
+        "repositories": List["RepositorySummaryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListRepositorySyncDefinitionsInputRequestTypeDef = TypedDict(
+    "_RequiredListRepositorySyncDefinitionsInputRequestTypeDef",
+    {
+        "repositoryName": str,
+        "repositoryProvider": RepositoryProviderType,
+        "syncType": Literal["TEMPLATE_SYNC"],
+    },
+)
+_OptionalListRepositorySyncDefinitionsInputRequestTypeDef = TypedDict(
+    "_OptionalListRepositorySyncDefinitionsInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListRepositorySyncDefinitionsInputRequestTypeDef(
+    _RequiredListRepositorySyncDefinitionsInputRequestTypeDef,
+    _OptionalListRepositorySyncDefinitionsInputRequestTypeDef,
+):
+    pass
+
+
+ListRepositorySyncDefinitionsOutputTypeDef = TypedDict(
+    "ListRepositorySyncDefinitionsOutputTypeDef",
+    {
+        "nextToken": str,
+        "syncDefinitions": List["RepositorySyncDefinitionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListServiceInstanceOutputsInputRequestTypeDef = TypedDict(
+    "_RequiredListServiceInstanceOutputsInputRequestTypeDef",
+    {
+        "serviceInstanceName": str,
+        "serviceName": str,
+    },
+)
+_OptionalListServiceInstanceOutputsInputRequestTypeDef = TypedDict(
+    "_OptionalListServiceInstanceOutputsInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListServiceInstanceOutputsInputRequestTypeDef(
+    _RequiredListServiceInstanceOutputsInputRequestTypeDef,
+    _OptionalListServiceInstanceOutputsInputRequestTypeDef,
+):
+    pass
+
+
+ListServiceInstanceOutputsOutputTypeDef = TypedDict(
+    "ListServiceInstanceOutputsOutputTypeDef",
+    {
+        "nextToken": str,
+        "outputs": List["OutputTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListServiceInstanceProvisionedResourcesInputRequestTypeDef = TypedDict(
+    "_RequiredListServiceInstanceProvisionedResourcesInputRequestTypeDef",
+    {
+        "serviceInstanceName": str,
+        "serviceName": str,
+    },
+)
+_OptionalListServiceInstanceProvisionedResourcesInputRequestTypeDef = TypedDict(
+    "_OptionalListServiceInstanceProvisionedResourcesInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListServiceInstanceProvisionedResourcesInputRequestTypeDef(
+    _RequiredListServiceInstanceProvisionedResourcesInputRequestTypeDef,
+    _OptionalListServiceInstanceProvisionedResourcesInputRequestTypeDef,
+):
+    pass
+
+
+ListServiceInstanceProvisionedResourcesOutputTypeDef = TypedDict(
+    "ListServiceInstanceProvisionedResourcesOutputTypeDef",
+    {
+        "nextToken": str,
+        "provisionedResources": List["ProvisionedResourceTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListServiceInstancesInputRequestTypeDef = TypedDict(
     "ListServiceInstancesInputRequestTypeDef",
     {
@@ -1071,6 +1472,68 @@ ListServiceInstancesOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListServicePipelineOutputsInputRequestTypeDef = TypedDict(
+    "_RequiredListServicePipelineOutputsInputRequestTypeDef",
+    {
+        "serviceName": str,
+    },
+)
+_OptionalListServicePipelineOutputsInputRequestTypeDef = TypedDict(
+    "_OptionalListServicePipelineOutputsInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListServicePipelineOutputsInputRequestTypeDef(
+    _RequiredListServicePipelineOutputsInputRequestTypeDef,
+    _OptionalListServicePipelineOutputsInputRequestTypeDef,
+):
+    pass
+
+
+ListServicePipelineOutputsOutputTypeDef = TypedDict(
+    "ListServicePipelineOutputsOutputTypeDef",
+    {
+        "nextToken": str,
+        "outputs": List["OutputTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListServicePipelineProvisionedResourcesInputRequestTypeDef = TypedDict(
+    "_RequiredListServicePipelineProvisionedResourcesInputRequestTypeDef",
+    {
+        "serviceName": str,
+    },
+)
+_OptionalListServicePipelineProvisionedResourcesInputRequestTypeDef = TypedDict(
+    "_OptionalListServicePipelineProvisionedResourcesInputRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListServicePipelineProvisionedResourcesInputRequestTypeDef(
+    _RequiredListServicePipelineProvisionedResourcesInputRequestTypeDef,
+    _OptionalListServicePipelineProvisionedResourcesInputRequestTypeDef,
+):
+    pass
+
+
+ListServicePipelineProvisionedResourcesOutputTypeDef = TypedDict(
+    "ListServicePipelineProvisionedResourcesOutputTypeDef",
+    {
+        "nextToken": str,
+        "provisionedResources": List["ProvisionedResourceTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListServiceTemplateVersionsInputRequestTypeDef = TypedDict(
     "_RequiredListServiceTemplateVersionsInputRequestTypeDef",
     {
@@ -1171,6 +1634,40 @@ ListTagsForResourceOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredNotifyResourceDeploymentStatusChangeInputRequestTypeDef = TypedDict(
+    "_RequiredNotifyResourceDeploymentStatusChangeInputRequestTypeDef",
+    {
+        "resourceArn": str,
+        "status": ResourceDeploymentStatusType,
+    },
+)
+_OptionalNotifyResourceDeploymentStatusChangeInputRequestTypeDef = TypedDict(
+    "_OptionalNotifyResourceDeploymentStatusChangeInputRequestTypeDef",
+    {
+        "deploymentId": str,
+        "outputs": Sequence["OutputTypeDef"],
+        "statusMessage": str,
+    },
+    total=False,
+)
+
+
+class NotifyResourceDeploymentStatusChangeInputRequestTypeDef(
+    _RequiredNotifyResourceDeploymentStatusChangeInputRequestTypeDef,
+    _OptionalNotifyResourceDeploymentStatusChangeInputRequestTypeDef,
+):
+    pass
+
+
+OutputTypeDef = TypedDict(
+    "OutputTypeDef",
+    {
+        "key": str,
+        "valueString": str,
+    },
+    total=False,
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -1181,6 +1678,16 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+ProvisionedResourceTypeDef = TypedDict(
+    "ProvisionedResourceTypeDef",
+    {
+        "identifier": str,
+        "name": str,
+        "provisioningEngine": ProvisionedResourceEngineType,
+    },
+    total=False,
+)
+
 RejectEnvironmentAccountConnectionInputRequestTypeDef = TypedDict(
     "RejectEnvironmentAccountConnectionInputRequestTypeDef",
     {
@@ -1196,6 +1703,133 @@ RejectEnvironmentAccountConnectionOutputTypeDef = TypedDict(
     },
 )
 
+RepositoryBranchInputTypeDef = TypedDict(
+    "RepositoryBranchInputTypeDef",
+    {
+        "branch": str,
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+
+RepositoryBranchTypeDef = TypedDict(
+    "RepositoryBranchTypeDef",
+    {
+        "arn": str,
+        "branch": str,
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+
+RepositorySummaryTypeDef = TypedDict(
+    "RepositorySummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+
+RepositorySyncAttemptTypeDef = TypedDict(
+    "RepositorySyncAttemptTypeDef",
+    {
+        "events": List["RepositorySyncEventTypeDef"],
+        "startedAt": datetime,
+        "status": RepositorySyncStatusType,
+    },
+)
+
+RepositorySyncDefinitionTypeDef = TypedDict(
+    "RepositorySyncDefinitionTypeDef",
+    {
+        "branch": str,
+        "directory": str,
+        "parent": str,
+        "target": str,
+    },
+)
+
+_RequiredRepositorySyncEventTypeDef = TypedDict(
+    "_RequiredRepositorySyncEventTypeDef",
+    {
+        "event": str,
+        "time": datetime,
+        "type": str,
+    },
+)
+_OptionalRepositorySyncEventTypeDef = TypedDict(
+    "_OptionalRepositorySyncEventTypeDef",
+    {
+        "externalId": str,
+    },
+    total=False,
+)
+
+
+class RepositorySyncEventTypeDef(
+    _RequiredRepositorySyncEventTypeDef, _OptionalRepositorySyncEventTypeDef
+):
+    pass
+
+
+_RequiredRepositoryTypeDef = TypedDict(
+    "_RequiredRepositoryTypeDef",
+    {
+        "arn": str,
+        "connectionArn": str,
+        "name": str,
+        "provider": RepositoryProviderType,
+    },
+)
+_OptionalRepositoryTypeDef = TypedDict(
+    "_OptionalRepositoryTypeDef",
+    {
+        "encryptionKey": str,
+    },
+    total=False,
+)
+
+
+class RepositoryTypeDef(_RequiredRepositoryTypeDef, _OptionalRepositoryTypeDef):
+    pass
+
+
+ResourceSyncAttemptTypeDef = TypedDict(
+    "ResourceSyncAttemptTypeDef",
+    {
+        "events": List["ResourceSyncEventTypeDef"],
+        "initialRevision": "RevisionTypeDef",
+        "startedAt": datetime,
+        "status": ResourceSyncStatusType,
+        "target": str,
+        "targetRevision": "RevisionTypeDef",
+    },
+)
+
+_RequiredResourceSyncEventTypeDef = TypedDict(
+    "_RequiredResourceSyncEventTypeDef",
+    {
+        "event": str,
+        "time": datetime,
+        "type": str,
+    },
+)
+_OptionalResourceSyncEventTypeDef = TypedDict(
+    "_OptionalResourceSyncEventTypeDef",
+    {
+        "externalId": str,
+    },
+    total=False,
+)
+
+
+class ResourceSyncEventTypeDef(
+    _RequiredResourceSyncEventTypeDef, _OptionalResourceSyncEventTypeDef
+):
+    pass
+
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -1207,6 +1841,17 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+RevisionTypeDef = TypedDict(
+    "RevisionTypeDef",
+    {
+        "branch": str,
+        "directory": str,
+        "repositoryName": str,
+        "repositoryProvider": RepositoryProviderType,
+        "sha": str,
+    },
+)
+
 S3ObjectSourceTypeDef = TypedDict(
     "S3ObjectSourceTypeDef",
     {
@@ -1487,6 +2132,31 @@ TagTypeDef = TypedDict(
     },
 )
 
+_RequiredTemplateSyncConfigTypeDef = TypedDict(
+    "_RequiredTemplateSyncConfigTypeDef",
+    {
+        "branch": str,
+        "repositoryName": str,
+        "repositoryProvider": RepositoryProviderType,
+        "templateName": str,
+        "templateType": TemplateTypeType,
+    },
+)
+_OptionalTemplateSyncConfigTypeDef = TypedDict(
+    "_OptionalTemplateSyncConfigTypeDef",
+    {
+        "subdirectory": str,
+    },
+    total=False,
+)
+
+
+class TemplateSyncConfigTypeDef(
+    _RequiredTemplateSyncConfigTypeDef, _OptionalTemplateSyncConfigTypeDef
+):
+    pass
+
+
 TemplateVersionSourceInputTypeDef = TypedDict(
     "TemplateVersionSourceInputTypeDef",
     {
@@ -1506,6 +2176,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
 UpdateAccountSettingsInputRequestTypeDef = TypedDict(
     "UpdateAccountSettingsInputRequestTypeDef",
     {
+        "pipelineProvisioningRepository": "RepositoryBranchInputTypeDef",
         "pipelineServiceRoleArn": str,
     },
     total=False,
@@ -1548,6 +2219,7 @@ _OptionalUpdateEnvironmentInputRequestTypeDef = TypedDict(
         "description": str,
         "environmentAccountConnectionId": str,
         "protonServiceRoleArn": str,
+        "provisioningRepository": "RepositoryBranchInputTypeDef",
         "spec": str,
         "templateMajorVersion": str,
         "templateMinorVersion": str,
@@ -1796,6 +2468,40 @@ UpdateServiceTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateTemplateSyncConfigInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateTemplateSyncConfigInputRequestTypeDef",
+    {
+        "branch": str,
+        "repositoryName": str,
+        "repositoryProvider": RepositoryProviderType,
+        "templateName": str,
+        "templateType": TemplateTypeType,
+    },
+)
+_OptionalUpdateTemplateSyncConfigInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateTemplateSyncConfigInputRequestTypeDef",
+    {
+        "subdirectory": str,
+    },
+    total=False,
+)
+
+
+class UpdateTemplateSyncConfigInputRequestTypeDef(
+    _RequiredUpdateTemplateSyncConfigInputRequestTypeDef,
+    _OptionalUpdateTemplateSyncConfigInputRequestTypeDef,
+):
+    pass
+
+
+UpdateTemplateSyncConfigOutputTypeDef = TypedDict(
+    "UpdateTemplateSyncConfigOutputTypeDef",
+    {
+        "templateSyncConfig": "TemplateSyncConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
